#[non_exhaustive]pub enum PushHintReason {
JournalAdvanced,
SnapshotInvalidated,
RegionChanged,
}Expand description
Reason a server suggests that the client perform a normal synchronization exchange.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
JournalAdvanced
The authoritative journal advanced beyond the hinted cursor.
SnapshotInvalidated
A previously captured bootstrap snapshot should no longer be resumed.
RegionChanged
The preferred serving region changed.