#[non_exhaustive]pub enum RejectionCode {
IdentityMismatch,
Unauthorized,
InvalidOperation,
BusinessRule,
Dependency,
SchemaIncompatible,
}Expand description
Stable machine-readable rejection categories.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IdentityMismatch
Request identity did not match the authenticated context.
The actor is not allowed to perform the operation.
InvalidOperation
Wire shape or bounded-field validation failed.
BusinessRule
The application rejected the operation’s business semantics.
Dependency
The operation depends on an unavailable or rejected operation.
SchemaIncompatible
Operation schema is outside the application’s compatibility window.